@@ -6,16 +6,19 @@
 @license: GNU GPL
 """
 import os
+import sys
 
 import gtk
 import hildon
 import gobject
 import osso
 from gnome import gnomevfs
+import dbus
 
 from wappushhandler import PushHandler
 import fmms_config as fMMSconf
 import controller as fMMSController
+import fmms_sender_ui as fMMSSenderUI
 
 import logging
 log = logging.getLogger('fmms.%s' % __name__)
@@ -70,17 +73,26 @@ class fMMS_Viewer(hildon.Program):
 		headers.set_label("Headers")
 		headers.connect('clicked', self.mms_menu_button_clicked, fname)
 		
+		reply = hildon.GtkButton(gtk.HILDON_SIZE_AUTO)
+		reply.set_label("Reply")
+		reply.connect('clicked', self.mms_menu_button_clicked, fname)
+		
+		menu.append(reply)
 		menu.append(headers)
 	
 		menu.show_all()
 		
 		return menu		
 	
+	
 	""" actions for mms menu """
 	def mms_menu_button_clicked(self, button, fname):
 		buttontext = button.get_label()
 		if buttontext == "Headers":
 			ret = self.create_headers_dialog(fname)
+		elif buttontext == "Reply":
+			number = self.cont.get_replyuri_from_transid(fname)
+			fMMSSenderUI.fMMS_SenderUI(tonumber=number).run()
 
 	""" show headers in a dialog """
 	def create_headers_dialog(self, fname):
@@ -185,22 +197,26 @@ class fMMS_Viewer(hildon.Program):
 	""" action on click on image/button """
 	def mms_img_clicked(self, widget, data):
 		log.info("img clicked: %s", data)
-		path = "file://" + data
+		path = str("file://" + data)
 		# gnomevfs seems to be better than mimetype when guessing mimetype for us
 		file_mimetype = gnomevfs.get_mime_type(path)
+		log.info("path: %s", path)
+		log.info("mimetype: %s", file_mimetype)
 		if file_mimetype != None:
 			if file_mimetype.startswith("video") or file_mimetype.startswith("audio"):
+				self.osso_c = osso.Context("fMMSViewer", "0.3", False)
 				rpc = osso.Rpc(self.osso_c)
 				rpc.rpc_run("com.nokia.mediaplayer", "/com/nokia/mediaplayer", "com.nokia.mediaplayer", "mime_open", (str, path))	
 			elif file_mimetype.startswith("image"):
+				self.osso_c = osso.Context("fMMSViewer", "0.3", False)
 				rpc = osso.Rpc(self.osso_c)
-				rpc.rpc_run("com.nokia.image_viewer", "/com/nokia/image_viewer", "com.nokia.image_viewer", "mime_open", (str, path))
+				ret = rpc.rpc_run("com.nokia.image_viewer", "/com/nokia/image_viewer", "com.nokia.image_viewer", "mime_open", (str, path))
 		else:
 			# TODO: how to solve this?
 			# move .mms to ~/MyDocs? change button to copy file to ~/MyDocs?
 			#rpc = osso.Rpc(self.osso_c)
 			#path = os.path.dirname(path).replace("file://", "")
-			log.info("path %s", path)
+			log.info("path %s", str(path))
 			#rpc.rpc_run("com.nokia.osso_filemanager", "/com/nokia/osso_filemanager", "com.nokia.osso_filemanager", "open_folder", (str, path))
 
 
@@ -221,5 +237,5 @@ class fMMS_Viewer(hildon.Program):
 		gtk.main()
 		
 if __name__ == "__main__":
-	app = fMMS_Viewer("fname", True)
+	app = fMMS_Viewer(sys.argv[1], True)
 	app.run()
\ No newline at end of file
