@@ -5,14 +5,16 @@
 @author: Nick Leppänen Larsson <frals@frals.se>
 @license: GNU GPL
 """
-import dbus, gobject
+import dbus
+import gobject
 import dbus.mainloop.glib
 import dbus.service
-import traceback
-import osso
-import gtk
-import sys
+
 from wappushhandler import PushHandler
+import controller as fMMSController
+
+import logging
+log = logging.getLogger('fmms.%s' % __name__)
 
 class MMSHandler(dbus.service.Object):
 	def __init__(self):
