@@ -6,9 +6,6 @@
 @license: GNU GPL
 """
 import sys
-from mms import message
-from mms.message import MMSMessage
-from mms import mms_pdu
 import os
 import dbus
 import urllib2
@@ -17,9 +14,18 @@ import httplib
 import conic
 import time
 import socket
-from dbus.mainloop.glib import DBusGMainLoop
 import array
+
+from dbus.mainloop.glib import DBusGMainLoop
+
+from mms import message
+from mms.message import MMSMessage
+from mms import mms_pdu
 import fmms_config as fMMSconf
+import controller as fMMSController
+
+import logging
+log = logging.getLogger('fmms.%s' % __name__)
 
 magic = 0xacdcacdc
 
@@ -27,18 +33,20 @@ _DBG = True
 
 class PushHandler:
 	def __init__(self):
+		self.cont = fMMSController.fMMS_controller()
+		# TODO: get all this from controller instead of config
 		self.config = fMMSconf.fMMS_config()
 		self._mmsdir = self.config.get_mmsdir()
 		self._pushdir = self.config.get_pushdir()
 		self._apn = self.config.get_apn()
 		self._apn_nicename = self.config.get_apn_nicename()
-		self._incoming = '/home/user/.fmms/temp/LAST_INCOMING'
+		self._incoming = self.config.get_imgdir() + "/LAST_INCOMING"
 		
 		if not os.path.isdir(self._mmsdir):
-			print "creating dir", self._mmsdir
+			log.info("creating dir %s", self._mmsdir)
 			os.makedirs(self._mmsdir)
 		if not os.path.isdir(self._pushdir):
-			print "creating dir", self._pushdir
+			log.info("creating dir %s", self._pushdir)
 			os.makedirs(self._pushdir)
 
 	""" handle incoming push over sms """
@@ -47,9 +55,8 @@ class PushHandler:
 		args = (source, src_port, dst_port, wsp_header, wsp_payload)
 		
 		# TODO: dont hardcode
-		if not os.path.isdir('/home/user/.fmms/temp'):
-			print "creating dir /home/user/.fmms/temp"
-			os.makedirs("/home/user/.fmms/temp")
+		if not os.path.isdir(self.config.get_imgdir()):
+			os.makedirs(self.config.get_imgdir())
 		
 		f = open(self._incoming, 'w')
 		for arg in args:
@@ -58,68 +65,38 @@ class PushHandler:
 		f.close()
 
 		if(_DBG):
-			print "SRC: ", source, ":", src_port
-			print "DST: ", dst_port
+			log.info("SRC: %s:%s", source, src_port)
+			log.info("DST: %s", dst_port)
 			#print "WSPHEADER: ", wsp_header
 			#print "WSPPAYLOAD: ", wsp_payload
 
-		data = []
-		# We didn't really want this, as we decode as MMS
-		# pretty bad idea to decode WSP header as MMS, I know :(
+		binarydata = []
+		# throw away the wsp_header!
 		#for d in wsp_header:
-		#	data.append(int(d))	
+		#	data.append(int(d))
+		
 		for d in wsp_payload:
-			data.append(int(d))
+			binarydata.append(int(d))
 
-		print "decoding..."
-		# decode the push message
-		decoder = mms_pdu.MMSDecoder()
-		#print data
-		wspdata = decoder.decodeCustom(data)
-		# extract some data we want to use
+		log.info("decoding...")
 		
-		sndr, url, trans_id = None, None, None
-		bus = dbus.SystemBus()
-		try:
-			url = wspdata["Content-Location"]
-			print "content-location:", url
-		except Exception, e:
-			print "no content-location in push; aborting...", e, e.args
-			proxy = bus.get_object('org.freedesktop.Notifications', '/org/freedesktop/Notifications')
-			interface = dbus.Interface(proxy,dbus_interface='org.freedesktop.Notifications')
-			interface.SystemNoteInfoprint ("fMMS: Failed to parse SMS PUSH.")
-		try:
-			sndr = wspdata["From"]
-			print "Sender:", sndr
-		except Exception, e:
-			print "exception on values from decode:", e, e.args
-			
-		try:
-			trans_id = wspdata["Transaction-Id"]
-			trans_id = str(trans_id)
-			print "transid:", trans_id
-		except Exception, e:
-			print "no transid in sms push; aborting...", e, e.args
-			proxy = bus.get_object('org.freedesktop.Notifications', '/org/freedesktop/Notifications')
-			interface = dbus.Interface(proxy,dbus_interface='org.freedesktop.Notifications')
-			interface.SystemNoteInfoprint ("fMMS: Failed to parse SMS PUSH.")
-			raise
 		
-		if sndr == None:
-			print "No sender... Setting to unknown"
-			sndr = "Unknown"
+		(data, sndr, url, trans_id) = self.cont.decode_mms_from_push(binarydata)
 		
-		# save to file
-		self._save_push_message(trans_id, wspdata)
-		# notify the user we got a new message
-		self._notify_mms(dbus_loop, sndr, "SMS Push for MMS received")
-		# get mms message
+		log.info("saving...")
+		# Controller should save it
+		pushid = self.cont.save_push_message(data)
+		log.info("notifying push...")
+		# Send a notify we got the SMS Push and parsed it A_OKEY!
+		self.notify_mms(dbus_loop, sndr, "SMS Push for MMS received")
+		log.info("fetching mms...")
 		path = self._get_mms_message(url, trans_id)
-		# decode it
-		self.decodeMMS(path)
-		#_create_html(path, sndr)
-		# notify the user we downloaded it
-		self._notify_mms(dbus_loop, sndr, "New MMS", trans_id);
+		log.info("decoding mms... path: %s", path)
+		message = self.cont.decode_binary_mms(path)
+		log.info("storing mms...")
+		mmsid = self.cont.store_mms_message(pushid, message)
+		log.info("notifying mms...")
+		self.notify_mms(dbus_loop, sndr, "New MMS", trans_id);
 		return 0
 
 
@@ -127,14 +104,12 @@ class PushHandler:
 	# TODO: implement this
 	def _incoming_ip_push(self, src_ip, dst_ip, src_port, dst_port, wsp_header, wsp_payload):
 		if(_DBG):
-			print "SRC: " + src_ip + ":" + src_port + "\n"
-			print "DST: " + dst_ip + ":" + dst_port + "\n"
-			print "WSPHEADER: " + wsp_header + "\n"
-			print "WSPPAYLOAD: " + wsp_payload + "\n"
-			print
+			log.info("SRC: %s:%s", src_ip, src_port)
+			log.info("DST: %s:%s", dst_ip, dst_port)
+
 
 	""" notifies the user with a org.freedesktop.Notifications.Notify, really fancy """
-	def _notify_mms(self, dbus_loop, sender, message, path=None):
+	def notify_mms(self, dbus_loop, sender, message, path=None):
 		bus = dbus.SystemBus()
 		proxy = bus.get_object('org.freedesktop.Notifications', '/org/freedesktop/Notifications')
 		interface = dbus.Interface(proxy,dbus_interface='org.freedesktop.Notifications')
@@ -142,65 +117,37 @@ class PushHandler:
 		if path == None:
 			interface.Notify('MMS', 0, '', message, sender, choices, {"category": "sms-message", "dialog-type": 4, "led-pattern": "PatternCommunicationEmail", "dbus-callback-default": "se.frals.fmms /se/frals/fmms se.frals.fmms open_gui"}, -1)
 		else:
-			# TODO: callback should open fMMS gui
 			interface.Notify("MMS", 0, '', message, sender, choices, {"category": "email-message", "dialog-type": 4, "led-pattern": "PatternCommunicationEmail", "dbus-callback-default": "se.frals.fmms /se/frals/fmms se.frals.fmms open_mms string:\"" + path + "\""}, -1)
 
-	""" saves the push message so we can reuse it """
-	def _save_push_message(self, transaction, decodeddata):
-		dirname = self._pushdir
-		if not os.path.isdir(dirname):
-			if(_DBG):
-				print "creating dir"
-			os.makedirs(dirname)
-
-		# write the data to file
-		fname = open(dirname + "/" + transaction, 'w')
-		for line in decodeddata:
-			if(_DBG):
-				print fname, ":", str(line), ":", decodeddata[line]
-			fname.write(str(line) + " ")
-			fname.write(str(decodeddata[line]))
-			fname.write("\n")
-		fname.close()
 
 	""" get the mms message from content-location """
 	""" thanks benaranguren on talk.maemo.org for patch including x-wap-profile header """
 	def _get_mms_message(self, location, transaction):
-		dirname = self._mmsdir + transaction
-		if not os.path.isdir(dirname):
-			if(_DBG):
-				print "creating dir"
-			os.makedirs(dirname)
-		print "getting file: ", location
+		log.info("getting file: %s", location)
 		try:
 			# TODO: remove hardcoded sleep
 			con = ConnectToAPN(self._apn_nicename)
-			time.sleep(6)
+			#time.sleep(6)
 			con.connect()
 			
-			### send the m-notifyresp-ind first
 			try:
 				notifyresp = self._send_notify_resp(transaction)
-				print "notifyresp sent"
-			except:
-				print "notify sending failed..."
+				log.info("notifyresp sent")
+			except Exception, e:
+				log.exception("notify sending failed: %s %s", type(e), e)
 			
-			# this seems to work like it should
-			# TODO: dont hardcode timeout
-			# god it would be nice with python2.6 for timeout= in urllib2
-			timeout = 60
+			# TODO: configurable time-out?
+			timeout = 30
 			socket.setdefaulttimeout(timeout)
 			(proxyurl, proxyport) = self.config.get_proxy_from_apn()
 			
 			if proxyurl == "" or proxyurl == None:
-				print "connecting without proxy"
-				#mmsdata = urllib2.urlopen(location)
+				log.info("connecting without proxy")
 			else:
 				proxyfull = str(proxyurl) + ":" + str(proxyport)
-				print "connecting with proxy", proxyfull	
+				log.info("connecting with proxy %s", proxyfull)
 				proxy = urllib2.ProxyHandler({"http": proxyfull})
 				opener = urllib2.build_opener(proxy)
-				#mmsdata = opener.open(location)
 				urllib2.install_opener(opener)
 				
 			#headers = {'x-wap-profile': 'http://mms.frals.se/n900.rdf'}
@@ -212,34 +159,33 @@ class PushHandler:
 				print mmsdata.info()
 			except:
 				pass
+			
 			mmsdataall = mmsdata.read()
-			fp = open(dirname + "/message", 'w')
-			fp.write(mmsdataall)
-			fp.close()
+			dirname = self.cont.save_binary_mms(mmsdataall, transaction)
 			
 			if(_DBG):
-				print "fetched ", location, " and wrote to file", fp
+				log.info("fetched %s and wrote to file", location)
 				
 			# send acknowledge we got it ok
 			try:
 				ack = self._send_acknowledge(transaction)
-				print "ack sent"
+				log.info("ack sent")
 			except:
-				print "sending ack failed"
+				log.exception("sending ack failed: %s %s", type(e), e)
 			
-			con.disconnect()
+			con.disconnect()			
 			
 		except Exception, e:
-			print e, e.args
-			print "removing dir..."
-			os.rmdir(dirname)
+			log.exception("fatal: %s %s", type(e), e)
 			bus = dbus.SystemBus()
 			proxy = bus.get_object('org.freedesktop.Notifications', '/org/freedesktop/Notifications')
 			interface = dbus.Interface(proxy,dbus_interface='org.freedesktop.Notifications')
 			interface.SystemNoteInfoprint ("fMMS: Failed to download MMS message.")
 			raise
+			
 		return dirname
 
+
 	def _send_notify_resp(self, transid):
 		mms = MMSMessage(True)
 		mms.headers['Message-Type'] = "m-notifyresp-ind"
@@ -247,49 +193,25 @@ class PushHandler:
 		mms.headers['MMS-Version'] = "1.3"
 		mms.headers['Status'] = "Deferred"
 		
-		print "setting up notify sender"
 		sender = MMSSender(customMMS=True)
-		print "sending notify..."
+		log.info("sending notify...")
 		out = sender.sendMMS(mms)
-		print "m-notifyresp-ind:", out
+		log.info("m-notifyresp-ind: %s", out)
 		return out
-		
+	
+	
 	def _send_acknowledge(self, transid):
 		mms = MMSMessage(True)
 		mms.headers['Message-Type'] = "m-acknowledge-ind"
 		mms.headers['Transaction-Id'] = transid
 		mms.headers['MMS-Version'] = "1.3"
 		
-		print "setting up ack sender"
 		ack = MMSSender(customMMS=True)
-		print "sending ack..."
+		log.info("sending ack...")
 		out = ack.sendMMS(mms)
-		print "m-acknowledge-ind:", out
+		log.info("m-acknowledge-ind: %s", out)
 		return out
 
-	""" decodes 'message'-file in path """
-	def decodeMMS(self, path):
-		# Decode the specified file
-		# This also creates all the parts as files in path
-		message = MMSMessage.fromFile(path + "/message")
-
-	""" deprecated, not in use """
-	def _create_html(self, path, sender):    
-		filelist = os.listdir(path)
-		html = "<html><head/><body>Sender:" + sender + "<br/>"
-		for fname in filelist:
-			(name, ext) = os.path.splitext(fname)
-			if ext == ".jpg":
-			    html += "<img src=\"" + str(name) + str(ext) + "\"/>"
-			elif ext == ".txt":
-			    fp = open(path + "/" + fname, 'r')
-			    content = fp.read()
-			    fp.close()
-			    html += "<br/>" + str(content)
-		html += "</body></html>"
-		file = open(path + "/MMS.html", 'w')
-		file.write(html)
-		file.close() 
        
 class ConnectToAPN:
 	def __init__(self, apn):
@@ -297,7 +219,8 @@ class ConnectToAPN:
 	    self.connection = conic.Connection()
 	    
 	def connection_cb(self, connection, event, magic):
-	    print "connection_cb(%s, %s, %x)" % (connection, event, magic)
+	    #print "connection_cb(%s, %s, %x)" % (connection, event, magic)
+	    pass
 
 	
 	def disconnect(self):
@@ -356,57 +279,58 @@ class MMSSender:
 		self._mms.addPage(slide)
 	
 	def sendMMS(self, customData=None):
+		mmsid = None
 		if customData != None:
-			print "using custom mms"
+			log.info("using custom mms")
 			self._mms = customData
-			
+	
 		mmsc = self.config.get_mmsc()
 		
 		(proxyurl, proxyport) = self.config.get_proxy_from_apn()
 		mms = self._mms.encode()
 		
-		### TEMP CODE ###
-		dirname = "/home/user/.fmms/sent/"
-		if not os.path.isdir(dirname):
-			print "creating dir"
-			os.makedirs(dirname)
-		fp = open(dirname + 'LAST_OUTGOING', 'wb')
-		fp.write(mms)
-		fp.close()
-		### END TEMP CODE ###
-		
-		#User-Agent: NokiaN95/11.0.026; Series60/3.1 Profile/MIDP-2.0 Configuration/CLDC-1.1 
 		headers = {'Content-Type':'application/vnd.wap.mms-message', 'User-Agent' : 'NokiaN95/11.0.026; Series60/3.1 Profile/MIDP-2.0 Configuration/CLDC-1.1', 'x-wap-profile' : 'http://mms.frals.se/n900.rdf'}
 		#headers = {'Content-Type':'application/vnd.wap.mms-message'}
 		if proxyurl == "" or proxyurl == None:
 			print "connecting without proxy"
+			mmsc = mmsc.lower()
 			mmsc = mmsc.replace("http://", "")
 			mmsc = mmsc.rstrip('/')
 			mmsc = mmsc.partition('/')
 			mmschost = mmsc[0]
 			path = "/" + str(mmsc[2])
-			print "mmschost:", mmschost, "path:", path, "pathlen:", len(path)
+			log.info("mmschost: %s path: %s pathlen: %s", mmschost, path, len(path))
 			conn = httplib.HTTPConnection(mmschost)
 			conn.request('POST', path , mms, headers)
 		else:
-			print "connecting via proxy " + proxyurl + ":" + str(proxyport)
-			print "mmschost:", mmsc
+			log.info("connecting via proxy %s:%s", proxyurl, str(proxyport))
+			log.info("mmschost: %s", mmsc)
 			conn = httplib.HTTPConnection(proxyurl + ":" + str(proxyport))
 			conn.request('POST', mmsc, mms, headers)
+
+		if customData == None:			
+			cont = fMMSController.fMMS_controller()
+			path = cont.save_binary_outgoing_mms(mms, self._mms.transactionID)
+			message = cont.decode_binary_mms(path)
+			mmsid = cont.store_outgoing_mms(message)	
 			
 		res = conn.getresponse()
-		print "MMSC STATUS:", res.status, res.reason
+		log.info("MMSC STATUS: %s %s", res.status, res.reason)
 		out = res.read()
-		print "MMSC RESPONDED:", out
-		
 		try:
 			decoder = mms_pdu.MMSDecoder()
 			data = array.array('B')
 			for b in out:
 				data.append(ord(b))
 			outparsed = decoder.decodeResponseHeader(data)
+			
+			if mmsid != None:
+				pushid = cont.store_outgoing_push(outparsed)
+				cont.link_push_mms(pushid, mmsid)
+				
 		except Exception, e:
-			print e, e.args
+			print type(e), e
 			outparsed = out
-		
+			
+		log.info("MMSC RESPONDED: %s", outparsed)
 		return res.status, res.reason, outparsed
\ No newline at end of file
